<template>
  <a-modal
    :confirm-loading='confirmLoading1'
    :visible='visible1'
    :width='1050'
    title='变量'
    @cancel='handleCancel'
    @ok='handleOk'
  >
    <a-layout>
      <a-layout-sider style='background: #fff' width='200'>
        <a-tree :expandedKeys.sync='expandedKeys' :tree-data='treeData' default-expand-all
                show-icon @select='onSelect'>
          <template #title='{ key: treeKey, title }'>
            <a-dropdown :trigger="['contextmenu']">
              <span>{{ title }}</span>
              <template #overlay>
                <a-menu @click='({ key: menuKey }) => addProjectModal(treeKey, menuKey)'>
                </a-menu>
              </template>
            </a-dropdown>
          </template>
        </a-tree>
      </a-layout-sider>
      <a-layout style='padding: 0 0 0 1px;overflow: hidden'>
        <a-layout :style="{ background: '#fff', padding: '1px', minHeight: '100%' }">
          <equipment v-if='indexStyle===2' ref='equipment' :parameter-group-id='parameterGroupId' />
          <parameter-group v-if='indexStyle===5' ref='equipment' :parameter-group-id='parameterGroupId' />
          <empty-parameter v-if='indexStyle===7' ref='equipment' :parameter-group-id='parameterGroupId'
                           @ok='emptySaveParameters' />
          <solid-parameter v-if='indexStyle===6' ref='equipment' :parameter-group-id='parameterGroupId'
                           @ok='saveParameters' />
        </a-layout>
      </a-layout>
    </a-layout>
  </a-modal>
</template>

<script>
import Equipment from './Equipment'
import SolidParameter from './SolidParameter'
import EmptyParameter from './EmptyParameter'
import ParameterGroup from './ParameterGroup'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import Server from '../../../../server/Server'
import pick from 'lodash.pick'
import { getAction } from '@/api/manage'

export default {
  name: 'ParameterAddress',
  mixins: [JeecgListMixin],
  components: {
    EmptyParameter,
    SolidParameter,
    ParameterGroup,
    Equipment,
    Server,
    JDictSelectTag,
    JInput,
    JEllipsis
  },
  data() {
    return {
      projectId: '',
      parameterGroupId: '',
      indexStyle: 2,
      expandedKeys: ['0'],
      selectedKeys: [],
      currentSelectedKeys: [],
      visible1: false,
      confirmLoading1: false,
      visible: false,
      disableSubmit: true,
      treeData: [],
      load: false,
      url: {
        tree: '/equipment/tree/collect',
        queryByProjectCode: '/projectClassify/queryByProjectCode',
        queryByServe: '/serve/deploy/queryByProjectCode',
        addBatch: '/empty/parameter/addBatch',
        edit: '/empty/parameter/edit'
      },
      form: this.$form.createForm(this),
      model: {}
    }
  },
  props: ['serverId'],
  watch: {
    serverId: {
      handler() {
        this.loadData()
      }
    }
  },
  methods: {
    openMqtt() {
      this.visible1 = true
    },
    generateList(data) {
      for (let i = 0; i < data.length; i++) {
        const node = data[i]
        const key = node.key
        this.expandedKeys.push(key)
        if (node.children) {
          this.generateList(node.children)
        }
      }
    },
    // 查询终端列表
    loadData() {
      if (this.serverId) {
        this.parameterGroupId = this.serverId
        // 根据虚设备id查询
        getAction(this.url.tree, { id: this.serverId }).then((res) => {
          if (res.success) {
            this.treeData = res.result
            this.generateList(this.treeData)
          }
          if (res.code === 510) {
            this.$message.warning(res.message)
          }
          this.loading = false
        })
      }
    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onSelectChange(selectedRowKeys) {
      this.selectedRowKeys = selectedRowKeys
    },
    modalFormOk(val) {
      // 调用父组件方法
      this.$emit('tree')
      // 新增/修改 成功时，重载列表
      this.loadData()
      this.selectedRowKeys = [val.id]
    },
    saveParameters(val) {
      if (val) {
        // 属性格式 IOT_设备编号_参数组编号_参数编号
        let parameter = 'IOT_' + val[0].eqptName + '_' + val[0].groupName + '_' + val[0].parameterName
        this.selectedRowKeys = [val.id]
        this.model = {}
        this.model.code = parameter
        this.model.type = val[0].parameterType
      } else {
        // 清空
      }
    },
    emptySaveParameters(val) {
      if (val) {
        // 属性格式 IOT_设备编号_参数组编号_参数编号
        let parameter = 'IOT_' + val[0].eqptName + '_' + val[0].parameterName
        this.selectedRowKeys = [val.id]
        this.model = {}
        this.model.code = parameter
        this.model.type = val[0].parameterType
      } else {
        // 清空
      }
    },
    searchQuery() {
      this.loadData()
      this.onClearSelected()
    },
    searchReset() {
      this.queryParam = {}
      this.loadData()
      this.onClearSelected()
    },
    handleCancel() {
      this.visible1 = false
    },
    add() {
      this.indexStyle = 2
      this.edit({})
      if (this.indexStyle === 2) {
        // 展示设备页面
        getAction(this.url.queryByServe, { projectCode: this.treeData[0].key.split('_')[1] }).then((res) => {
          if (res.success) {
            this.parameterGroupId = res.result.id
            this.indexStyle = 2
          }
        })
      }
    },
    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'parameterCode', 'parameterName', 'parameterDescribe', 'address'))
      })
    },
    handleOk() {
      // 调用父组件方法存储参数
      this.$emit('ok', this.model)
      this.visible1 = false
    },
    onSelect(selectedKeys) {
      if (selectedKeys.length === 0) {
        return
      }
      this.currentSelectedKeys = selectedKeys
      switch (selectedKeys[0].split('_')[0]) {
        case 'fwq':
          getAction(this.url.queryByServe, { projectCode: selectedKeys[0].split('_')[1] }).then((res) => {
            if (res.success) {
              this.parameterGroupId = res.result.id
              this.indexStyle = 2
            }
          })
          break
        case 'group':
          // 参数组
          this.parameterGroupId = selectedKeys[0].split('_')[1]
          this.indexStyle = 5
          break
        case 'ssb':
          this.parameterGroupId = selectedKeys[0].split('_')[1]
          this.indexStyle = 6
          break
        // 传入选中的参数
        case 'xxb':
          this.parameterGroupId = selectedKeys[0].split('_')[1]
          this.indexStyle = 7
          break
      }
    },
    close() {
      this.$emit('close')
      this.visible = false
    }
  }
}
</script>
<style lang='less' scoped>
/deep/ .ant-modal {
  height: 80%;

  .ant-modal-content {
    height: 100%;

    .ant-modal-body {
      height: calc(100% - 52.8px - 54.8px);


      .ant-layout {
        height: 100%;

        .ant-layout-sider {
          height: 100%;
          overflow: auto;
        }
      }

    }
  }
}
</style>

